searchNodes=[{"ref":"RemoteIp.html","title":"RemoteIp","type":"module","doc":"A plug to overwrite the Plug.Conn&#39;s remote_ip based on request headers. To use, add the RemoteIp plug to your app&#39;s plug pipeline: defmodule MyApp do use Plug.Builder plug RemoteIp end Keep in mind the order of plugs in your pipeline and place RemoteIp as early as possible. For example, if you were to add RemoteIp afterthe Plug Router, your route action&#39;s logic would be executed before the remote_ip actually gets modified - not very useful! There are 3 options that can be passed in: :headers - A list of strings naming the req_headers to use when deriving the remote_ip. Order does not matter. Defaults to ~w[forwarded x-forwarded-for x-client-ip x-real-ip]. :proxies - A list of strings in CIDR notation specifying the IPs of known proxies. Defaults to []. Loopback and private IPs are always appended to this list: 127.0.0.0/8 ::1/128 fc00::/7 10.0.0.0/8 172.16.0.0/12 192.168.0.0/16 Since these IPs are internal, they often are not the actual client address in production, so we add them by default. To override this behavior, whitelist known client IPs using the :clients option. :clients - A list of strings in CIDR notation specifying the IPs of known clients. Defaults to []. An IP in any of the ranges listed here will never be considered a proxy. This takes precedence over the :proxies option, including loopback/private addresses. Any IP that is not covered by :clients or :proxies is assumed to be a client IP. For example, suppose you know: you are behind proxies in the 1.2.x.x block the proxies use the X-Foo, X-Bar, and X-Baz headers but the IP 1.2.3.4 is actually a client, not one of the proxies Then you could say defmodule MyApp do use Plug.Builder plug RemoteIp, headers: ~w[x-foo x-bar x-baz], proxies: ~w[1.2.0.0/16], clients: ~w[1.2.3.4/32] end Note that, due to limitations in the inet_cidr library used to parse them, :proxies and :clients must be written in full CIDR notation, even if specifying just a single IP. So instead of &quot;127.0.0.1&quot; and &quot;a:b::c:d&quot;, you would use &quot;127.0.0.1/32&quot; and &quot;a:b::c:d/128&quot;. For more details, refer to the README on GitHub."},{"ref":"RemoteIp.html#call/2","title":"RemoteIp.call/2","type":"function","doc":"Callback implementation for Plug.call/2."},{"ref":"RemoteIp.html#from/2","title":"RemoteIp.from/2","type":"function","doc":"Standalone function to extract the remote IP from a list of headers. It&#39;s possible to get a subset of headers without access to a full Plug.Conn struct. For instance, when using Phoenix sockets, your socket&#39;s connect/3 callback may only be receiving :x_headers in the connect_info. Such situations make it inconvenient to use RemoteIp outside of a plug pipeline. Therefore, this function will fetch the remote IP from a plain list of header key-value pairs (just as you&#39;d have in the req_headers of a Plug.Conn). You may optionally specify the same options as if you were using RemoteIp as a plug: they&#39;ll be processed by RemoteIp.init/1 each time you call this function. If a remote IP cannot be parsed from the given headers (e.g., if the list is empty), this function will return nil. Examples iex&gt; RemoteIp.from([{&quot;x-forwarded-for&quot;, &quot;1.2.3.4&quot;}]) {1, 2, 3, 4} iex&gt; [{&quot;x-foo&quot;, &quot;1.2.3.4&quot;}, {&quot;x-bar&quot;, &quot;2.3.4.5&quot;}] ...&gt; |&gt; RemoteIp.from(headers: ~w[x-foo]) {1, 2, 3, 4} iex&gt; [{&quot;x-foo&quot;, &quot;1.2.3.4&quot;}, {&quot;x-bar&quot;, &quot;2.3.4.5&quot;}] ...&gt; |&gt; RemoteIp.from(headers: ~w[x-bar]) {2, 3, 4, 5} iex&gt; [{&quot;x-foo&quot;, &quot;1.2.3.4&quot;}, {&quot;x-bar&quot;, &quot;2.3.4.5&quot;}] ...&gt; |&gt; RemoteIp.from(headers: ~w[x-baz]) nil"},{"ref":"RemoteIp.html#init/1","title":"RemoteIp.init/1","type":"function","doc":"Callback implementation for Plug.init/1."},{"ref":"RemoteIp.Config.html","title":"RemoteIp.Config","type":"module","doc":"The internal configuration used by RemoteIp. This module is for internal use. It defines a struct that holds the options parsed out of the keywords given to RemoteIp.init/1. Users should pass keywords into the plug macro (or into RemoteIp.from/2) as documented by RemoteIp. The only real difference between the keywords users would pass and the fields held by this struct is that the struct uses more efficient data structures that have been preprocessed by RemoteIp.init/1: headers - Forwarding headers converted to a MapSet for efficient membership checks. proxies - Known proxy IP ranges parsed by InetCidr.parse/1. clients - Known client IP ranges parsed by InetCidr.parse/1."},{"ref":"RemoteIp.Config.html#t:cidr/0","title":"RemoteIp.Config.cidr/0","type":"type","doc":""},{"ref":"RemoteIp.Config.html#t:clients/0","title":"RemoteIp.Config.clients/0","type":"type","doc":""},{"ref":"RemoteIp.Config.html#t:headers/0","title":"RemoteIp.Config.headers/0","type":"type","doc":""},{"ref":"RemoteIp.Config.html#t:proxies/0","title":"RemoteIp.Config.proxies/0","type":"type","doc":""},{"ref":"RemoteIp.Config.html#t:t/0","title":"RemoteIp.Config.t/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.html","title":"RemoteIp.Headers","type":"module","doc":"Entry point for parsing any type of forwarding header."},{"ref":"RemoteIp.Headers.html#considering/1","title":"RemoteIp.Headers.considering/1","type":"function","doc":""},{"ref":"RemoteIp.Headers.html#parse/2","title":"RemoteIp.Headers.parse/2","type":"function","doc":"Selects the appropriate headers and parses IPs out of them. headers - The entire list of the Plug.Conn req_headers allowed - The list of headers RemoteIp is configured to look for, converted to a MapSet for efficiency The actual parsing is delegated to the RemoteIp.Headers.* submodules: &quot;forwarded&quot; is parsed by RemoteIp.Headers.Forwarded everything else is parsed by RemoteIp.Headers.Generic"},{"ref":"RemoteIp.Headers.html#t:allowed/0","title":"RemoteIp.Headers.allowed/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.html#t:header/0","title":"RemoteIp.Headers.header/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.html#t:ip/0","title":"RemoteIp.Headers.ip/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.html#t:key/0","title":"RemoteIp.Headers.key/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.html#t:value/0","title":"RemoteIp.Headers.value/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.Forwarded.html","title":"RemoteIp.Headers.Forwarded","type":"module","doc":"RFC 7239 compliant parser for Forwarded headers."},{"ref":"RemoteIp.Headers.Forwarded.html#parse/1","title":"RemoteIp.Headers.Forwarded.parse/1","type":"function","doc":"Given a Forwarded header&#39;s string value, parses out IP addresses from the for= parameter. Examples iex&gt; RemoteIp.Headers.Forwarded.parse(&quot;for=1.2.3.4;by=2.3.4.5&quot;) [{1, 2, 3, 4}] iex&gt; RemoteIp.Headers.Forwarded.parse(&quot;for=\\&quot;[::1]\\&quot;, for=\\&quot;[::2]\\&quot;&quot;) [{0, 0, 0, 0, 0, 0, 0, 1}, {0, 0, 0, 0, 0, 0, 0, 2}] iex&gt; RemoteIp.Headers.Forwarded.parse(&quot;invalid&quot;) []"},{"ref":"RemoteIp.Headers.Forwarded.html#t:header/0","title":"RemoteIp.Headers.Forwarded.header/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.Forwarded.html#t:ip/0","title":"RemoteIp.Headers.Forwarded.ip/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.Generic.html","title":"RemoteIp.Headers.Generic","type":"module","doc":"Generic parser for forwarding headers. When there is no other special RemoteIp.Headers.* parser submodule, RemoteIp.Headers.parse/2 will use this module to parse the header value. So, RemoteIp.Headers.Generic is used to parse X-Forwarded-For, X-Real-IP, X-Client-IP, and generally unrecognized headers."},{"ref":"RemoteIp.Headers.Generic.html#parse/1","title":"RemoteIp.Headers.Generic.parse/1","type":"function","doc":"Parses a comma-separated list of IPs. Any amount of whitespace is allowed before and after the commas, as well as at the beginning/end of the input. Examples iex&gt; RemoteIp.Headers.Generic.parse(&quot;1.2.3.4, 5.6.7.8&quot;) [{1, 2, 3, 4}, {5, 6, 7, 8}] iex&gt; RemoteIp.Headers.Generic.parse(&quot; ::1 &quot;) [{0, 0, 0, 0, 0, 0, 0, 1}] iex&gt; RemoteIp.Headers.Generic.parse(&quot;invalid&quot;) []"},{"ref":"RemoteIp.Headers.Generic.html#t:header/0","title":"RemoteIp.Headers.Generic.header/0","type":"type","doc":""},{"ref":"RemoteIp.Headers.Generic.html#t:ip/0","title":"RemoteIp.Headers.Generic.ip/0","type":"type","doc":""}]